summaryrefslogtreecommitdiffstats
path: root/tools/lib/h5diff.c
diff options
context:
space:
mode:
Diffstat (limited to 'tools/lib/h5diff.c')
-rw-r--r--tools/lib/h5diff.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/tools/lib/h5diff.c b/tools/lib/h5diff.c
index c7f9265..5fa88bd 100644
--- a/tools/lib/h5diff.c
+++ b/tools/lib/h5diff.c
@@ -1076,12 +1076,12 @@ hsize_t diff (hid_t file1_id,
{
char *buf1 = NULL;
char *buf2 = NULL;
- H5L_linkinfo_t li1;
- H5L_linkinfo_t li2;
+ H5L_info_t li1;
+ H5L_info_t li2;
- if (H5Lget_linkinfo (file1_id, path1, &li1, H5P_DEFAULT) < 0)
+ if(H5Lget_info(file1_id, path1, &li1, H5P_DEFAULT) < 0)
goto out;
- if (H5Lget_linkinfo (file1_id, path1, &li2, H5P_DEFAULT) < 0)
+ if(H5Lget_info(file1_id, path1, &li2, H5P_DEFAULT) < 0)
goto out;
/* Only external links will have a query function registered */
@@ -1128,7 +1128,7 @@ hsize_t diff (hid_t file1_id,
else
{
/* If one or both of these links isn't an external link, we can only
* compare information from H5Lget_linkinfo since we don't have a query
* function registered for them. */
/* If the link classes or the buffer length are not the
@@ -1128,7 +1128,7 @@ hsize_t diff (hid_t file1_id,
{
/* If one or both of these links isn't an external link, we can only
- * compare information from H5Lget_linkinfo since we don't have a query
+ * compare information from H5Lget_info since we don't have a query
* function registered for them. */
/* If the link classes or the buffer length are not the